ULinkRouteResolver typedef
ULinkRouteResolver =
String? Function(ULinkResolvedData data)
A function type that defines how to resolve ULink data to a route path.
Takes ULinkResolvedData and returns a nullable String representing the route path. Return null if the link should not be handled by routing.
Implementation
typedef ULinkRouteResolver = String? Function(ULinkResolvedData data);